@@ -13,16 +13,14 @@
 ;;;;
 ;;;; You should have received a copy of the GNU General Public License
 ;;;; along with this program; if not, write to the Free Software
-;;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+;;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 (require 'asdf)
 (require 'sb-posix)
-(require 'cl-ppcre)
 
-(push #p"/Users/dl/lisp-stuff/registry/" asdf:*central-registry*)
 (asdf:oos 'asdf:load-op 'createnode)
 
 (sb-ext:save-lisp-and-die "createnode"
  :executable t
- :toplevel #'Scat.create-node::toplevel
- :purify t)
+ :toplevel #'Scat.create-node-bin::toplevel
+ :purify NIL)
